@@ -21,7 +21,6 @@ from xml.etree.ElementTree import SubElement
 
 from automx2 import DomainNotFound
 from automx2 import InvalidServerType
-from automx2.util import socket_type_needs_ssl
 from automx2.generators import ConfigGenerator
 from automx2.generators import xml_to_string
 from automx2.ldap import LookupResult
@@ -30,6 +29,7 @@ from automx2.model import Davserver
 from automx2.model import Domain
 from automx2.model import Server
 from automx2.util import expand_placeholders
+from automx2.util import socket_type_needs_ssl
 
 NS_REQUEST = 'http://schemas.microsoft.com/exchange/autodiscover/outlook/requestschema/2006'
 NS_RESPONSE_PAYLOAD = 'http://schemas.microsoft.com/exchange/autodiscover/outlook/responseschema/2006a'
@@ -39,6 +39,12 @@ DAVSERVER_TYPE_MAP = {
     'caldav': 'CalDAV',
     'carddav': 'CardDAV',
 }
+ENCRYPTION_TYPE_MAP = {
+    'Auto': 'Auto',
+    'None': 'None',
+    'SSL': 'SSL',
+    'STARTTLS': 'TLS',
+}
 SERVER_TYPE_MAP = {
     'imap': 'IMAP',
     'pop': 'POP3',
@@ -76,6 +82,9 @@ class OutlookGenerator(ConfigGenerator):
         SubElement(element, 'Port').text = str(server.port)
         SubElement(element, 'LoginName').text = login_name
         SubElement(element, 'SSL').text = self.on_off(socket_type_needs_ssl(server.socket_type))
+        if server.socket_type in ENCRYPTION_TYPE_MAP:
+            # [MS-OXDSCLI]-v20210817: If present, the Encryption element overrides the SSL element
+            SubElement(element, 'Encryption').text = ENCRYPTION_TYPE_MAP[server.socket_type]
 
     @staticmethod
     def user_element(parent: Element, display_name: str) -> None:
